Type Definition authenticator::Result
source · pub type Result<T> = Result<T, GAError>;Expand description
A type alias that can be used for fallible functions with google_authenticator.
pub type Result<T> = Result<T, GAError>;A type alias that can be used for fallible functions with google_authenticator.